# -*- coding: utf-8 -*-
# Generated by Django 1.11.11 on 2018-06-17 18:02
from __future__ import unicode_literals

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('django_cowhite_cms', '0001_initial'),
    ]

    operations = [
        migrations.RemoveField(
            model_name='page',
            name='categories',
        ),
        migrations.DeleteModel(
            name='Category',
        ),
    ]



from django.shortcuts import render, get_object_or_404
from django.views import generic as generic_views
from django.core.paginator import Paginator, EmptyPage, PageNotAnInteger
from django.shortcuts import render
from django.conf import settings

from .models import *


class PageView(generic_views.TemplateView):
    template_name = "django_cowhite_cms/page.html"

    def get_context_data(self, *args, **kwargs):
        context = super(PageView, self).get_context_data(*args, **kwargs)
        context['page'] = get_object_or_404(Page, slug=kwargs['slug'])
        if hasattr(settings, 'DISQUS_SHORT_NAME'):
            context['disqus_short_name'] = settings.DISQUS_SHORT_NAME
        return context




from django.db import models
from django.utils.text import slugify
from django.conf import settings


PUBLISH_STATUS_CHOICE_DRAFT = 'D'
PUBLISH_STATUS_CHOICE_PUBLISHED = 'P'

PUBLISH_STATUS_CHOICES = (
    (PUBLISH_STATUS_CHOICE_DRAFT, 'Draft'),
    (PUBLISH_STATUS_CHOICE_PUBLISHED, 'Published'),
)


class DateTimeBase(models.Model):
    created_at = models.DateTimeField(auto_now_add=True)
    updated_at = models.DateTimeField(auto_now=True)

    class Meta:
        abstract = True

    def generate_unique_slug(self):
        title = self.title
        if self.slug:
            return self.slug
        slug_initial = slugify(self.title)
        slug = slug_initial
        model = self.__class__
        i = 1
        while True:
            try:
                model.objects.get(slug=slug)
                slug = "%s%s" % (slug_initial, i)
                i += 1
                continue
            except model.DoesNotExist:
                break
        return slug


class Page(DateTimeBase):
    title = models.CharField(max_length=500)
    slug = models.SlugField(max_length=500, unique=True, blank=True)
    cover_image = models.ImageField(
        upload_to='blog_post_images', null=True, blank=True)
    content = models.TextField()
    status = models.CharField(
        choices=PUBLISH_STATUS_CHOICES, max_length=1,
        default=PUBLISH_STATUS_CHOICE_DRAFT)
    published_date = models.DateTimeField(null=True, blank=True, auto_now_add=True)
    allow_comments = models.BooleanField(default=True)
    author = models.ForeignKey(settings.AUTH_USER_MODEL)

    # SEO
    seo_title = models.CharField(max_length=500,
        help_text='Optional. This title is inserted in HTML Title tag. If not filled, blog title will be used.',
        blank=True)
    seo_description = models.TextField(null=True, blank=True,
        help_text='Optional. This description is inserted in HTML meta description tag.'
        'If not filled, the first paragraph from the content will be inserted here.')
    seo_keywords = models.TextField(null=True, blank=True,
        help_text='Optional. This is not auto generated. The filled content will be'
        'inserted in meta keywords tag')

    def __unicode__(self):
        return u"%s" % self.title

    def __str__(self):
        return "%s" % self.title

    def save(self, *args, **kwargs):
        if not self.slug:
            self.slug = self.generate_unique_slug()
        if not self.seo_title:
            self.seo_title = self.title
        if not self.seo_description:
            self.seo_description = "%s..." % self.content.split("\n")[0][:250]
        super(Page, self).save(*args, **kwargs)





import os
from setuptools import find_packages, setup

with open(os.path.join(os.path.dirname(__file__), 'README.md')) as readme:
    README = readme.read()

# allow setup.py to be run from any path
os.chdir(os.path.normpath(os.path.join(os.path.abspath(__file__), os.pardir)))

setup(
    name='django-cowhite-cms',
    version='0.3.1',
    packages=find_packages(),
    include_package_data=True,
    license='MIT License',
    description='A simple Django cms. As of now only pages are supported. Blog is available in another package django-cowhite-blog',
    long_description=README,
    url='https://github.com/cowhite/django-cowhite-cms',
    author='Cowhite Software Pvt Ltd',
    author_email='hello@cowhite.com',
    python_requires=">=2.7,<=3.6",
    install_requires=["django >= 1.11, < 1.12"],
    classifiers=[
        'Environment :: Web Environment',
        'Framework :: Django',
        'Framework :: Django :: 1.11',  # replace "X.Y" as appropriate
        'Intended Audience :: Developers',
        'License :: OSI Approved :: MIT License',  # example license
        'Operating System :: OS Independent',
        'Programming Language :: Python',
        # Replace these appropriately if you are stuck on Python 2.
        'Programming Language :: Python :: 2.7',
        'Programming Language :: Python :: 3',
        'Programming Language :: Python :: 3.4',
        'Programming Language :: Python :: 3.5',
        'Topic :: Internet :: WWW/HTTP',
        'Topic :: Internet :: WWW/HTTP :: Dynamic Content',
    ],
)
